
	loc date: display %tdCCYY-NN-DD =daily("`c(current_date)'", "DMY")
	cap log close
	log using "${user}/output/log/02c_PDS_imputation_2011_`date'.log", replace

	/* =============================================================================
		Project	        : India poverty estimates - 2011-12 & 2022-23 
		Dofile			: 02c_PDS_imputation_2011
		Last modified	: 25th March 2025
		
		Inputs MMRP		: "${user}/data/processed/ces/master_consumption_2011.dta" 
						  "${user}/data/processed/ces/master_item_list_2011.dta"
						  "${user}/data/processed/ces/master_hh_2011.dta"
					
		Inputs URP		: (To increase sample for median calculation)
						  "${user}/data/processed/ces/block0506_2011_urp.dta"
						  "${user}/data/processed/ces/block0102_2011_urp.dta"
						  "${user}/data/processed/ces/block03a_2011_urp.dta"
					
		Outputs			: "${user}/data/processed/ces/temp/hh_pds_mkt_mmrp_2011.dta"
						  "${user}/data/processed/ces/temp/hh_pds_mkt_urp_2011.dta"
						  "${user}/data/processed/ces/all_pds_items_2011.dta"
						  "${user}/data/processed/ces/temp/med_price_a_`i'.dta"				
						  "${user}/data/processed/ces/pds_imputed_uv_vector_2011.dta"
									
		Steps 			:  * 0. Define Hierarchy of Price Levels
						   * 1. Clean data - MMRP 
						   * 2. Clean data - URP
						   * 3. Append URP and MMRP ALL-PDS-RELATED households
						   * 4. Find Medians based on MARKET PURCHASES only 
						   * 5. Merge Medians into ALL-PDS-RELATED dataset
						   * 6. Discard implicitly negative subsidies		
						   * 7. Find Most Local Valid Imputation
						   * 8. Reshape back to long
						   * 9. Save imputed vector for Core Poverty
			
	============================================================================= */

	*****************************************************************************
	** STEP 0. Define Hierarchy of Price Levels
	*****************************************************************************
	*Define locals for levels 
	loc varlist rice wheat sugar kerosene
	foreach item of loc varlist {
				loc level1 = "state sector sss month"
				loc level2 = "state sector month"
				loc level3 = "state month"
				loc level4 = "sector month"
				loc level5 = "month"
				loc level6 = "national"
	}
	
	*****************************************************************************
	* STEP 1. Median price calculation  - MMRP
	*****************************************************************************	
		
	*Start with processed data in 2011-12
	
	use "${user}/data/processed/ces/master_consumption_2011.dta", replace
	merge m:1 item using "${user}/data/processed/ces/master_item_list_2011.dta", keepusing(item_desc unit recall_period) keep(3) nogen
	merge m:1 hhid using "${user}/data/processed/ces/master_hh_2011.dta", keepusing(state sector district hhsize pwt hhw sss) keep(3) nogen	
	
	*Only keep items and variables needed
	keep if inlist(item, 101, 102, 107, 108, 171, 172, 334, 335)
	tab item_desc
	tab item
		
	*Only keep market purchase for items purchased from other sources (non-PDS)
	keep if source==1 
	tostring hhid, replace
	
	*Check if any household has missing or zero value and quantity
	unique hhid 	if value_total==. 	| value_total==0
	unique hhid 	if qty_total==. 	| qty_total==0

	*Quantities are in grams and ML. Converting to kg and litre
	replace qty_total = qty_total/1000
	keep hhid item qty_total value_total hhsize hhwt pwt state sector district sss survey_month
		
	*Reshape wide to have one observation per household
	reshape wide qty_total value_total, i(hhid) j(item)
	
	*Renaming variables
		ren qty_total101 qty_pds_rice
		ren qty_total102 qty_mkt_rice
		ren qty_total107 qty_pds_wheat
		ren qty_total108 qty_mkt_wheat
		ren qty_total171 qty_pds_sugar
		ren qty_total172 qty_mkt_sugar
		ren qty_total334 qty_pds_kerosene
		ren qty_total335 qty_mkt_kerosene
	
		ren value_total101 value_pds_rice
		ren value_total102 value_mkt_rice
		ren value_total107 value_pds_wheat
		ren value_total108 value_mkt_wheat
		ren value_total171 value_pds_sugar
		ren value_total172 value_mkt_sugar
		ren value_total334 value_pds_kerosene
		ren value_total335 value_mkt_kerosene
	
	*Calculate unit prices
	loc varlist rice wheat sugar kerosene 
	foreach var of loc varlist {
		g double up_pds_`var'= value_pds_`var'/qty_pds_`var'
		g double up_mkt_`var'= value_mkt_`var'/qty_mkt_`var'
			replace up_pds_`var'= . if value_pds_`var'==0 | value_pds_`var'==.
			replace up_mkt_`var'= . if value_mkt_`var'==0 | value_mkt_`var'==.
		lab var up_pds_`var' "Unit price - PDS `var'"
		lab var up_mkt_`var' "Unit price - market `var'"		
	}
		
	*Creating dummies for PDS and market purchase
	loc varlist rice wheat sugar kerosene 
	foreach var of loc varlist {
		g pds_`var' = (qty_pds_`var'!= . & value_pds_`var'!= .) 
		g mkt_`var' = (qty_mkt_`var'!= . & value_mkt_`var'!= .)
			lab var pds_`var' "Dummy for PDS purchase - `var'"
			lab var mkt_`var' "Dummy for market purchase - `var'"
	}
		
	*Label quantity and value variables
	loc varlist rice wheat sugar kerosene 
	foreach var of loc varlist {
		lab var qty_pds_`var' 	"Total quantity consumed at HH level - PDS `var'"
		lab var qty_mkt_`var' 	"Total quantity consumed at HH level - market `var'"
		lab var value_pds_`var' "HH expenditure on - PDS `var'"
		lab var value_mkt_`var' "HH expenditure on - market `var'"
	}
	
	g national = "India"	
	order hhid state sector pds_* mkt_* up_pds_* up_mkt_* qty_pds_* qty_mkt_* value_pds_* value_mkt_* 
	tab state	
	
	g data = "MMRP"
	tostring sss, replace
	save "${user}/data/processed/ces/temp/hh_pds_mkt_mmrp_2011.dta", replace

	* ******************************************************************************
	* STEP 2. Median price calculation - URP
	********************************************************************************
		
	*Start with URP processed data and adjust states to match with states in 2022-23 
	use "${user}/data/processed/ces/block0506_2011_urp.dta", clear
	merge m:1 hhid using "${user}/data/processed/ces/block0102_2011_urp.dta", keepusing(state sector sss) keep(3) nogen
	merge m:1 item using "${user}/data/processed/ces/master_item_list_2011.dta", keepusing(recall_period item_desc unit) keep(3) nogen
	
	*Only keep items and variables needed
	keep if inlist(item, 101, 102, 107, 108, 171, 172, 334, 335)
	
	*Only keep market purchase for items purchased from other sources (non-PDS)
	keep if source==1 
	
	keep hhid state sector item item_desc recall_period unit qty_total value_total
	tostring hhid, replace
	
	*Check if any household has missing or zero value and quantity
	unique hhid if value_total==. | value_total==0
	unique hhid if qty_total==. | qty_total==0
	
	*Quantities are in grams and ML. Converting to kg and litre
	replace qty_total = qty_total/1000
	
	keep hhid item qty_total value_total
	
	*Reshape wide to have one observation per household
	reshape wide qty_total value_total, i(hhid) j(item)
	
	*Merge with household level data to bring back the households that do not consume either of the 8 items (1727 HHs)
	*Keep ALL the households and not just the households that were merged
	merge m:1 hhid using "${user}/data/processed/ces/block0102_2011_urp.dta", keepusing(state sector district sss fsu hamlet survey_date)
	
	*Dummy for household not consuming any of the 8 items
	g hh_none = _m==2	
	drop _m
	drop if hh_none==1
	
	*g str_date = string(survey_date, "%06.0f") 
	
	*Create survey month
	g month = substr(survey_date, 3,2)
	g year1 = substr(survey_date, -2,2)
	
	destring month, replace

	clonevar month_temp =month
	replace month_temp = 0 if mi(month)		
 	bys state sector fsu hamlet (month_temp): 	g temp = month_temp[_N] 
	bys state sector fsu (month_temp): 			replace temp = month_temp[_N]  if temp==0

	bys state sector fsu hamlet (month_temp): 	g temp2 = year1[_N] 
	bys state sector fsu (month_temp): 		replace temp2 = year1[_N] if mi(year1)

	replace month = temp if mi(month)
	replace year1 = temp2 if mi(year1)
	
	drop month_temp temp temp2
	
	replace year1 = "2012" if year1=="12"
	replace year1 = "2011" if year1=="11"	
	destring year1, replace
	
	g survey_month = ym(year1, month)
		format survey_month %tm
			
	*Merge with household level data to get weights
	merge 1:1 hhid using  "${user}/data/processed/ces/block03a_2011_urp.dta", keepusing(hhsize hhwt) keep(3) nogen
		
	*Calculate population weights
	g pwt = hhwt*hhsize
			
	*Create Telangana and Ladakh; merge Diu Daman and Dadra Nagar Haveli 
	clonevar district_new = district
	clonevar state_new = state
		
		*Combining Daman & Diu and Dadra & Nagar Haveli
		recode district_new (1=3) if state==26
		replace state_new = 25 if district_new==3 & state==26
			
		*Splitting J&K and Ladakh
		//note: districts 7 (Leh) & 8 (Kargil) were taken from J&K to create Ladakh
		replace state_new = 37 if (district_new==7|district_new==8) & state==1
		recode district_new (7=1) (8=2) if state_new==37	

		*Splitting Andhra and Telangana 
		//note: district 1-10 were taken from Andhra to create Telangana
		replace state_new = 36 if (inrange(district_new,1,10) & state==28)
		recode district_new (11=1) (12=2) (13=3) (14=4) (15=5) (16=6) (17=7) (18=8) (19=9) (20=10) (21=11) (22=12) (23=13) if state_new==28

		#delimit ; 
		lab define state_lab 	1 "Jammu & Kashmir" 
								2 "Himachal Pradesh" 
								3 "Punjab" 
								4 "Chandigarh" 
								5 "Uttrakhand" 
								6 "Haryana" 
								7 "Delhi"
								8 "Rajasthan" 
								9 "Uttar Pradesh" 
								10 "Bihar" 
								11 "Sikkim" 
								12 "Arunachal Pradesh" 
								13 "Nagaland" 
								14 "Manipur" 
								15 "Mizoram" 
								16 "Tripura" 
								17 "Meghalaya" 
								18 "Assam" 
								19 "West Bengal" 
								20 "Jharkhand" 
								21 "Odisha" 
								22 "Chhattisgarh" 
								23 "Madhya Pradesh" 
								24 "Gujarat" 
								25 "Daman & Diu & D & N Haveli" 
								27 "Maharashtra" 
								28 "Andhra Pradesh" 
								29 "Karnataka" 
								30 "Goa" 
								31 "Lakshadweep" 
								32 "Kerala" 
								33 "Tamil Nadu" 
								34 "Puducherry"
								35 "A & N Island" 
								36 "Telangana" 
								37 "Ladakh" ;
		lab val state_new state_lab;
		#delimit cr
	
		** Change variable names to match 2022-23 
		ren state state_2011
		ren district district_2011
		ren state_new state
		ren district_new district
		lab var state "States matching 2022"
	
	drop hhwt district_2011 district
	
		*Renaming variables
		ren qty_total101 qty_pds_rice
		ren qty_total102 qty_mkt_rice
		ren qty_total107 qty_pds_wheat
		ren qty_total108 qty_mkt_wheat
		ren qty_total171 qty_pds_sugar
		ren qty_total172 qty_mkt_sugar
		ren qty_total334 qty_pds_kerosene
		ren qty_total335 qty_mkt_kerosene
		
		ren value_total101 value_pds_rice
		ren value_total102 value_mkt_rice
		ren value_total107 value_pds_wheat
		ren value_total108 value_mkt_wheat
		ren value_total171 value_pds_sugar
		ren value_total172 value_mkt_sugar
		ren value_total334 value_pds_kerosene
		ren value_total335 value_mkt_kerosene
	
	*Calculate unit prices
	loc varlist rice wheat sugar kerosene 
	foreach var of loc varlist {
		g double up_pds_`var'= value_pds_`var'/qty_pds_`var'
		g double up_mkt_`var'= value_mkt_`var'/qty_mkt_`var'
		lab var up_pds_`var' "Unit price - PDS `var'"
		lab var up_mkt_`var' "Unit price - market `var'"		
	}
		
	*Creating dummies for PDS and market purchase
	loc varlist rice wheat sugar kerosene 
	foreach var of loc varlist {
		g pds_`var' = qty_pds_`var'!= . & value_pds_`var'!= . 
		g mkt_`var' = qty_mkt_`var'!= . & value_mkt_`var'!= . 
		lab var pds_`var' "Dummy for PDS purchase - `var'"
		lab var mkt_`var' "Dummy for market purchase - `var'"
	}
	
	*Label quantity and value variables
	loc varlist rice wheat sugar kerosene 
	foreach var of loc varlist {
		lab var qty_pds_`var' "Total quantity consumed at HH level - PDS `var'"
		lab var qty_mkt_`var' "Total quantity consumed at HH level - market `var'"
		lab var value_pds_`var' "HH expenditure on - PDS `var'"
		lab var value_mkt_`var' "HH expenditure on - market `var'"
	}
	
	g national = "India"	
	order hhid state sector pds_* mkt_* up_pds_* up_mkt_* qty_pds_* qty_mkt_* value_pds_* value_mkt_*
	keep  hhid state sector pds_* mkt_* up_pds_* up_mkt_* qty_pds_* qty_mkt_* value_pds_* value_mkt_* survey_month ///
	sss hh_none hhsize pwt national
	g data = "URP"
	
	tab state
	save "${user}/data/processed/ces/temp/hh_pds_mkt_urp_2011.dta", replace

	*****************************************************************************
	** 3. Append URP and MMRP ALL-PDS-RELATED households
	*****************************************************************************
	use "${user}/data/processed/ces/temp/hh_pds_mkt_mmrp_2011.dta", clear
		append using "${user}/data/processed/ces/temp/hh_pds_mkt_urp_2011.dta" // MUST BE APPENDED. DIFFERENT HHs. 
		save "${user}/data/processed/ces/all_pds_items_2011.dta", replace

	*****************************************************************************
	** 4. Find Medians based on MARKET PURCHASES only 
	*****************************************************************************
	use "${user}/data/processed/ces/all_pds_items_2011.dta", clear
	ren survey_month month
	// Drop irrelevant HH (only consuming from PDS). Though the long format will still keep some HHs that are not relevant for all Mkt PDS eqivalents
	keep if mkt_wheat==1 | mkt_sugar==1 | mkt_kerosene==1 | mkt_rice==1
	
	*Make sure there are no zero or missing mkt prices for households consuming from the market
	count if inlist(up_mkt_rice,0,.) 		& mkt_rice==1
	count if inlist(up_mkt_wheat,0,.) 		& mkt_wheat==1
	count if inlist(up_mkt_sugar,0,.) 		& mkt_sugar==1
	count if inlist(up_mkt_kerosene,0,.) 	& mkt_kerosene==1
				
	*Calculate median price at each level and store in a tempfile - Level 1 to 5
	loc varlist rice wheat sugar kerosene  		
	foreach item of loc varlist {
		forval i = 1/6 {
		preserve
		collapse (median) mkt_med_`item'_`i' =  up_mkt_`item' (count) freq_`item'_`i' = up_mkt_`item' if mkt_`item'==1 [aw=pwt], by(`level`i'')
		tempfile med_price_`item'_a_`i'
		save `med_price_`item'_a_`i'', replace
		restore
	}
	}

	*Merge temp files - for each item and level	
	forval i = 1/6 {
	use `med_price_rice_a_`i'', clear
	loc varlist wheat sugar kerosene  		
	foreach item of loc varlist {
			merge 1:1 `level`i'' using `med_price_`item'_a_`i'', keep(3) nogen
			save "${user}/data/processed/ces/temp/med_price_a_`i'.dta", replace
	}
	}

	*****************************************************************************
	** 5. Merge Medians into ALL-PDS-RELATED dataset
	*****************************************************************************
	*Bring median prices back to the dataset	
	use "${user}/data/processed/ces/all_pds_items_2011.dta", clear
	ren survey_month month
		forval i = 1/6 {
		merge m:1 `level`i'' using "${user}/data/processed/ces/temp/med_price_a_`i'",  nogen //Do not restrict to _m==3
	}
	su mkt_med_rice_*
	
	*****************************************************************************
	** 6. Discard implicitly negative subsidies
	*****************************************************************************
	// From now on, we don't care about HH's purchasing in market. Only about the PDS-purchases.
	*Dummy for purchasing any item from PDS shops
	
	g pds_any = 1 if pds_rice==1 | pds_wheat==1 | pds_sugar==1 | pds_kerosene==1
		lab var pds_any 			"Dummy for household buying any item from PDS"
		keep if pds_any==1 

	* Identify negative subsidy: everytime market price is lower than paid price for PDS items
	loc varlist rice wheat sugar kerosene  		
	foreach item of loc varlist {
	forval i = 1/6 {
		g neg_subs_`item'_`i' = (mkt_med_`item'_`i' < up_pds_`item') & mkt_med_`item'_`i'!=. 
		lab var neg_subs_`item'_`i' "Flag for HH (originally) receiving negative subsidy, under `item'_`i'"
		di in red "# Households with implied negative subsidy after puchasing item `item', using imputation level `i'"
		count if neg_subs_`item'_`i'==1 & pds_`item'==1
		}
		di in red "% Households with implied negative subsidy after puchasing item `item' through PDS"
		sum neg_subs_`item'_* if pds_`item'==1
		}

	* Invalidate imputation whenever implied subsidy is negative_subs_`item
	loc varlist rice wheat sugar kerosene  		
	foreach item of loc varlist {
	forval i = 1/6 {
		replace mkt_med_`item'_`i' =. if neg_subs_`item'_`i' ==1	
		}
		}
			
	*****************************************************************************
	** 7. Find Most Local Valid Imputation
	*****************************************************************************
	loc varlist rice wheat sugar kerosene  		
		foreach item of loc varlist {
			// PROBLEM WITH LOOP: NOT SURE IT WAS ALLOWING FOR MISSING OVERALL RESULT?
				loc i = 1 
						g double md_mkt_`item' = mkt_med_`item'_`i'
						g level_`item' = `i'
									
				loc j = `i'+ 1
						replace md_mkt_`item' =  mkt_med_`item'_`j' if freq_`item'_`i' < 50 | inlist(md_mkt_`item', 0, .)
						replace level_`item' = `j' if freq_`item'_`i' < 50 | inlist(md_mkt_`item', 0, .)
									
				loc k = `i'+ 2
						replace md_mkt_`item' =  mkt_med_`item'_`k' if freq_`item'_`j' < 50 | inlist(md_mkt_`item', 0, .)
						replace level_`item' = `k' if freq_`item'_`j' < 50 | inlist(md_mkt_`item', 0, .)
									
				loc l = `i'+ 3
						replace md_mkt_`item' =  mkt_med_`item'_`l' if freq_`item'_`k' < 50 | inlist(md_mkt_`item', 0, .)
						replace level_`item' = `l' if freq_`item'_`k' < 50 | inlist(md_mkt_`item', 0, .)

				loc m = `i'+ 4
						replace md_mkt_`item' =  mkt_med_`item'_`m' if freq_`item'_`l' < 50 | inlist(md_mkt_`item', 0, .)
						replace level_`item' = `m' if freq_`item'_`l' < 50 | inlist(md_mkt_`item', 0, .)
									
				loc n = `i'+ 5
						replace md_mkt_`item' =  mkt_med_`item'_`n' if freq_`item'_`m' < 50 | inlist(md_mkt_`item', 0, .)
						replace level_`item' = `n' if freq_`item'_`m' < 50 | inlist(md_mkt_`item', 0, .)
									
		lab var md_mkt_`item' "Median market price - `item'"
		lab var level_`item' "Level at which median market prices get assigned - `item'"
		
		di in red "# Invalid final imputations, due to either negative subs or insufficient sample, for `item'"
		count if  md_mkt_`item' ==. & pds_`item'==1 		// Because data is wide (instead of long), we can't drop invalid observations yet
		g invalid_md_mkt_`item' = (md_mkt_`item' ==.) if pds_`item'==1
		tab invalid_md_mkt_`item'  
			}		
		
	*Check if the median price is missing for any item
	mdesc md_* // This command is not helpful due to wide format. Captures any HH. Must restrict.
		
	di in red "# HHs with invalid imputations"
	codebook hhid if md_mkt_rice 		==.	& pds_rice==1	
	codebook hhid if md_mkt_sugar 		==.	& pds_sugar==1	
	codebook hhid if md_mkt_wheat 		==.	& pds_wheat==1	
	codebook hhid if md_mkt_kerosene 	==.	& pds_kerosene==1	
	
	// Trick to keep track of invalid imputations 
	loc varlist rice wheat sugar kerosene  		
	foreach item of loc varlist {
	replace md_mkt_`item' = 9999999999 if md_mkt_`item' ==.	& pds_`item'==1	
	}
			
	lab var pwt 		"Population weights"
	lab var national 	"National dummy"
	keep hhid state sector sss national md_* pds_* level_* pwt data
	sort hhid state sector

	/****************************************************************************
	* 8. Reshape back to long
	*****************************************************************************/

	ren pds_rice pds101
	ren pds_wheat pds107
	ren pds_sugar pds171
	ren pds_kerosene pds334
	
	ren md_mkt_rice 	uv_imputed_pds101
	ren md_mkt_wheat 	uv_imputed_pds107
	ren md_mkt_sugar 	uv_imputed_pds171
	ren md_mkt_kerosene uv_imputed_pds334
	
	ren level_rice 		imputed_lev101
	ren level_wheat 	imputed_lev107
	ren level_sugar 	imputed_lev171
	ren level_kerosene 	imputed_lev334
	
	codebook hhid // Data should only have 77,730 HHs
	keep pds101 pds107 pds171 pds334 uv_imputed_pds* imputed_lev* hhid state sector data 
	reshape long pds uv_imputed_pds imputed_lev, i(hhid state sector data) j(item)
	/* The re-shaing has artifically adding PDS==0 that should not be in vector. 
	Example of hhid=="410001204" in MMRP. Need to drop manually. */
	
	/****************************************************************************
	** 9. Save imputed vector for Core Poverty
	*****************************************************************************/
	* 9.1 - Drop artifically introduced purchases in PDS (due to reshape)
	drop if pds!=1
	codebook hhid // Ok after droping atifical observations
	
	* 9.2 - Drop invalid imputations because of sample size (could not drop in step 7 because of wide format)
	g pds_imputed_valid = uv_imputed_pds!=9999999999 
	tab pds_imputed_valid 
		replace  uv_imputed_pds=. if uv_imputed_pds==9999999999
		keep if pds_imputed_valid ==1
		
	* 9.3 - Tidy up
	lab var uv_imputed_pds 	"Imputed price"
	lab var imputed_lev 	"Level at which price is imputed"
	lab var data 			"MMRP or URP"
	lab def imputed_lev ///
		1 "state sector sss month" ///
		2 "state sector month" ///
		3 "state month" ///
		4 "sector month" 
	lab val imputed_lev "pds_imputed_lev"
	g item_list = "."
		replace item_list = "Rice - PDS" 		if item==101
		replace item_list = "Wheat - PDS" 		if item==107
		replace item_list = "Sugar - PDS" 		if item==171
		replace item_list = "Kerosene - PDS" 	if item==334
	lab var item_list "Item description"
	sort hhid state sector item
	g stamp ="$S_DATE $S_TIME"
	g scenario = "7 - Most local >50 obs"
	g note = "after adjusting grains and omitting imputations if SUBS<0"
	
	*9.4 - Save vector with URP & MMRP (for records only)
	save "${user}/data/processed/ces/pds_imputed_uv_vector_2011_mmrp_urp.dta", replace

	* 9.5 - Keep only MMRP subsample for poverty estimates
	keep if data=="MMRP"
	lab var data "MMRP or URP"
	
	*9.6 - Save final vector
	save "${user}/data/processed/ces/pds_imputed_uv_vector_2011.dta", replace
	
	*===============================================================================
	di in red "THE END OF 02c_PDS_imputation_2011" 
	*===============================================================================
	cap log close
	exit