	loc date: display %tdCCYY-NN-DD =daily("`c(current_date)'", "DMY")
	cap log close
	log using "${user}/output/log/02e_nonfood_school_imputation_`date'", replace

	/* =============================================================================
		Project			: India poverty estimates - 2011-12 & 2022-23
		Dofile			: 02e_nonfood_school_imputation.do
		Last modified	: 25th March 2025

		Inputs 2022		: "${user}/data/processed/ces/master_hh_2022.dta"
						  "${user}/data/processed/ces/master_consumption_2022.dta"
						  "${user}/data/processed/ces/master_item_list_2022.dta"
						  "${user}/data/processed/ces/level11_2022.dta"
						  "${user}/data/processed/ces/level07_2022.dta"
								
		Outputs 		: "${user}/data/processed/ces/master_free_nonfood_school_2022.dta"
						  "${user}/data/processed/ces/nonfood_school_imputed_2022.dta"
						
		Steps			: *0: Set up
						  *1: data on households receiving free clothing and footwear
						  *2: Data on market purchases of free items
						  *3: Aggregate data on market purchases of free items
						  *4: Merge household characteristics, no. attending educational institute, and free item details
						  *5: Estimate Unit Values using aggregate value and qty for footwear
						  *6: For clothing, estimate unit value as value/no. persons attending educational institute
						  *7: Estimate weighted medians from market purchases of the items
						  *8: Merge medians to impute value of free items
						  *9: Impute unit values using Most-Local scenario (7)
						  *10: Estimate imputed value of free items received when attending government educational institutes
					
	============================================================================= */
	*============================================================================*
	 di in red "STEP 0: Set up" 
	*============================================================================*
	loc time month 	// Substitute for name of time variable

	* Define hierarchy of aggregation
	loc aggr1 = "product `time' state sector sss" 
	loc aggr2 = "product `time' state sector"  
	loc aggr3 = "product `time' state"  		
	loc aggr4 = "product `time' sector"  		
	loc aggr5 = "product `time' "  		
	loc aggr6 = "product "  			

		
	*============================================================================*
	di in red "STEP 1: data on households receiving free clothing and footwear" 
	*============================================================================*
	use "${user}/data/processed/ces/level11_2022.dta", clear
	* add survey month
		destring hhno year, replace	
			bys fsu sss: g survey_seq= "1-2-3" if inlist(hhno, 1, 4, 7, 10, 13, 16) & subsample=="1"
			bys fsu sss: replace survey_seq= "1-3-2" if inlist(hhno, 2,5,8,11,14,17) & subsample=="1"
			bys fsu sss: replace survey_seq= "2-1-3" if inlist(hhno, 3,6,9,12,15,18) & subsample=="1"
			bys fsu sss: replace survey_seq= "2-3-1" if inlist(hhno, 1, 4, 7, 10, 13, 16) & subsample=="2"
			bys fsu sss: replace survey_seq= "3-1-2" if inlist(hhno, 2,5,8,11,14,17) & subsample=="2"
			bys fsu sss: replace survey_seq= "3-2-1" if inlist(hhno, 3,6,9,12,15,18) & subsample=="2"
			lab var survey_seq "1: FDQ 2:CSQ 3:DGQ"

		split survey_seq, p("-") 
		destring survey_seq1 survey_seq2 survey_seq3, replace
		
		g seq = .
		foreach j of numlist 1(1)3{
				replace seq = 1 if  survey_seq1==`j' 
				replace seq = 2 if  survey_seq2==`j' 
				replace seq = 3 if  survey_seq3==`j' 		
			}
			
		g temp_month = .
		foreach p of numlist 1(1)10{
			replace temp_month = 6 + `p' + seq if panel==`p' 
		}
		
		g survey_month = .
		foreach m of numlist 8(1)19 {
			replace survey_month = tm(2022m8) - 8 + `m' if temp_month==`m'
		}
		format survey_month %tm
		
	keep hhid survey year fsu nss_region clothing_free num_clothing_free footwear_free num_footwear_free survey_month
	
	clonevar month = survey_month 
	
	* Merge information on schooling
	merge m:1 hhid using "${user}/data/processed/ces/level07_2022.dta", keepusing(edu_institution num_govt_institution num_pvt_institution) keep(3) nogen
	
	* Merge household characteristics and weights
	merge 1:1 hhid using "${user}/data/processed/ces/master_hh_2022.dta", keepusing(state sector district hhsize pwt hhw sss) nogen	
	
	* Reshape data to make it at item level 
	ren clothing_free dummy_free2 
	ren footwear_free dummy_free1
	ren num_clothing_free num_free2 
	ren num_footwear_free num_free1
	
	reshape long dummy_free num_free , i(hhid) j(product)
	label val product prod_type
	
	save "${user}/data/processed/ces/master_free_nonfood_school_2022.dta", replace 

	*============================================================================*
	di in red "STEP 2: Data on market purchases of free items" 
	*============================================================================*
	use "${user}/data/processed/ces/master_consumption_2022.dta", clear
	clonevar month = survey_month
 
	* Keep market purchase information for LPG cylinders and relevant items (used by MOSPI) for imputations of uniforms, shoes.  
	keep if inlist(item, 356, 357, 390, 394)

	* Merge commodity charateristics
	merge m:1 item using "${user}/data/processed/ces/master_item_list_2022.dta", keepusing(commodity_group unit item_desc recall_period survey_type product_code ) keep(3) nogen
	
	*============================================================================*
	di in red "STEP 3: Aggregate data on market purchases of free items" 
	*============================================================================*
	* Aggregate categories for clothing and footwear - recall periods 365 days
	g product = 1 if inlist(item, 390, 394) 
	replace product = 2 if inlist(item, 356, 357) 
	lab def prod_typ 1 "footwear" 2 "clothing"
	lab val product prod_type
	
	* Aggregate value and quantity at household level 
	collapse (sum) value = value_total (sum) qty = qty_total , by(hhid product month)

	*============================================================================*
	di in red "STEP 4: Merge household characteristics, no. attending educational institute, and free item details"  
	*============================================================================*
	*Merge household characteristics and weights
	merge m:1 hhid using "${user}/data/processed/ces/master_hh_2022.dta", keepusing(state sector district hhsize pwt hhw sss) keep(3) nogen	
	
	*Merge information on schooling
	merge m:1 hhid using "${user}/data/processed/ces/level07_2022.dta", keepusing(edu_institution num_govt_institution num_pvt_institution) keep(3) nogen
		
	egen num_edu_inst = rowtotal(num_govt_institution num_pvt_institution)
		lab var num_edu_inst "Total persons attending any educational institute in the last 365 days"
		
	*============================================================================*
	di in red "STEP 5: Estimate Unit Values using aggregate value and qty for footwear" 
	*============================================================================*
	* Unit value paid for footwear .  
	g double uv_mkt_mospi = value/qty  if product==1

	*============================================================================*
	di in red "STEP 6: For clothing, estimate unit value as value/no. persons attending educational institute" 
		* Variable `_mospi' uses exact way specified in MOSPI report. However, this may overestimate value and therefore, we improve on it
	*============================================================================*
	* Clothing unit value 
	replace uv_mkt_mospi = value/num_govt_institution if product == 2  //for all households value is spread over all students in govt edu inst
	lab var uv_mkt_mospi "Unit value as estimated in the MOSPI report"
	
	* MOSPI definition of unit value - Unit value for households with children attending any/govt educational institution
		* To be sure that medians are not imputed over HHs for students outside govt inst. 
	g double uv_mkt_govtedu_mospi = .
		replace uv_mkt_govtedu_mospi = uv_mkt_mospi if ~inlist(num_govt_institution, 0, .)		
	lab var uv_mkt_govtedu_mospi "unit value, HHs with >1 in govt inst"
	
	*============================================================================*
	di in red "STEP 7: Estimate weighted medians from market purchases of the items" 
	*============================================================================*
	* Estimate weighted medians - Impute unit value over households with at least one member attending a govt institution
		forval y=1/6 {
		di in red "* Estimate weighted median within aggr`y' = `aggr`y'' *"
		set type double
		preserve
		collapse (median) uv_mkt_govtedu_mospi_med`y' = uv_mkt_govtedu_mospi (count) uv_mkt_govtedu_mospi_freq`y'=uv_mkt_govtedu_mospi [aw=pwt], by(`aggr`y'')
			tempfile uv`y'
			save `uv`y'' 
		restore
		}

	*============================================================================*
	 di in red "STEP 8: Merge medians to impute value of free items"
	*============================================================================*		
	use "${user}/data/processed/ces/master_free_nonfood_school_2022.dta", clear	
			
	* Merge imputed unit values into main dataset
		forval y=1/6 {
			merge m:1 `aggr`y'' using `uv`y'' 
			drop if _merge==2 
			drop _merge
			}
		
	* sort data to check output
	sort product state month sector sss

	
	*==========================================================================*
	 di in red "STEP 9: Impute unit values using Most-Local scenario (7)"
	 * Difference from MOSPI method 
		* unit value is estimated as value/all members attending govt  educational institution
		* imputed values estimated over households with at least 1 member attending a government institution
		* cannot assign a reasonable value to anyone not attending a govt institution. some other free clothing is going to households with no educational institute attendance, in which case such value attribution is tricky.
	*==========================================================================*

	* Use most local (lowest number) scenario,  st. sample size >50
	g double uv_imputed_med = .
	g double uv_imputed_freq = .
	g loc_lev = .
	g loc_lev_var = ""
	g uv_imputed_valid =.	
	
forval y=1/6 {
	replace loc_lev 		= `y' 				if (uv_mkt_govtedu_mospi_freq`y'>50 & uv_mkt_govtedu_mospi_freq`y'<.) & uv_imputed_med==.
	replace loc_lev_var 	= "`aggr`y''" 		if (uv_mkt_govtedu_mospi_freq`y'>50 & uv_mkt_govtedu_mospi_freq`y'<.) & uv_imputed_med==.
	replace uv_imputed_med 		= uv_mkt_govtedu_mospi_med`y' 	if (uv_mkt_govtedu_mospi_freq`y'>50 & uv_mkt_govtedu_mospi_freq`y'<.) & uv_imputed_med==.
	replace uv_imputed_freq 	= uv_mkt_govtedu_mospi_freq`y'	if (uv_mkt_govtedu_mospi_freq`y'>50 & uv_mkt_govtedu_mospi_freq`y'<.) & uv_imputed_med!=.
	replace uv_imputed_valid 	= 1 			if uv_imputed_med!=. 
	la var uv_mkt_govtedu_mospi_med`y'  	"Median unit value, HHs with >1 in govt inst, @ `aggr`y''"
	la var uv_mkt_govtedu_mospi_freq`y'  	"Sample size of unit value, HHs with >1 in govt inst, @ `aggr`y''"
	}
	la var uv_imputed_med 		"Median unit price, imputed"
	la var loc_lev 				"Local level used, >50 obs"
	lab define loc_lev 1 		"`aggr1'" 2 "`aggr2'" 3 "`aggr3'" 4 "`aggr4'" 5 "`aggr5'" 6 "`aggr6'" 99 "Invalid imputation" 
		replace loc_lev =99 if !inlist(loc_lev, 1, 2, 3, 4, 5, 6)
	lab val loc_lev loc_lev
	
	assert uv_imputed_freq==. if uv_imputed_med==. // Make sure frequencies are well captured

	di in red "Items with invalid imputation"
	// No invalids
	tab uv_imputed_valid, m
	tab uv_imputed_valid product if dummy_free == 1 & product == 1 , m
	tab uv_imputed_valid product if dummy_free == 1 & product == 2 , m
	tab uv_imputed_valid product if dummy_free == 1 & product == 1 & ~inlist(num_govt_institution, 0, .), m
	tab uv_imputed_valid product if dummy_free == 1 & product == 2 & ~inlist(num_govt_institution, 0, .), m
	
	*============================================================================*
	di in red "STEP 10: Estimate imputed value of free items received when attending government educational institutes" 
		* Impute value of free clothing and shoes received in the past 365 days, using the imputed unit values for HHs with at least 1 member attending a govt institution
	*============================================================================*
	* Impute value only for households with govt educational institution attendance
	g double value_imputed_nf = . 
		replace value_imputed_nf = num_free*uv_imputed_med if dummy_free == 1 & product == 1 & ~inlist(num_govt_institution, 0, .)
		replace value_imputed_nf = num_free*uv_imputed_med if dummy_free == 1 & product == 2 & ~inlist(num_govt_institution, 0, .)
	
	lab var value_imputed_nf "Imputed value of `product' for members attending a Govt Educational Institute"
	// IMPORTANT: All values and quantities in the original and consistent recall period of 365 days
		
	keep hhid product uv_imputed_med value_imputed_nf dummy_free num_free num_govt_institution survey_month uv_imputed_valid
	keep if dummy_free==1 & ~inlist(num_govt_institution, 0, .)
	assert value_imputed_nf!=.
		
* Create new item codes that will help us merge into consumption data.
	g item = .
		replace item = 901 if product==1	// imputed shoes 
		replace item = 900 if product==2 	// imputed uniforms 
	
	g product_code = 9001 if inlist(item, 356, 357, 900) //School uniform
		replace product_code = 9002 if inlist(item, 390, 394, 901) //School shoes
	
	g value_total		= 0 // Effectively paid 0 for free items in the market
	clonevar qty_total	= num_free
	clonevar qty_new	= num_free
	clonevar nf_imputed_valid	= uv_imputed_valid
	g year = 2022
	g source = . 
		
	keep hhid item product_code value_imputed_nf value_total qty_total year source survey_month qty_new nf_imputed_valid 
	
	save "${user}/data/processed/ces/nonfood_school_imputed_2022.dta", replace

	* ==========================================================================*
	di in red "THE END OF 02e_nonfood_school_imputation" 
	* ==========================================================================*
	cap log close
	exit