
	loc date: display %tdCCYY-NN-DD =daily("`c(current_date)'", "DMY")
	cap log close
	log using "${user}/output/log/06_welfare_agg${s}_`date'", replace

	/* =============================================================================
	Project			: India poverty estimates - 2011-12 & 2022-23 
	Dofile			: 06_welfare_agg${s}
	Last modified	: 26th March 2025

	Inputs 2011		: "${user}/data/processed/ces/master_consumption_wy_2011${s}.dta"
					  "${user}/data/processed/ces/master_item_list_2011.dta"
					  "${user}/data/processed/ces/master_hh_2011.dta"
					  "${user}/data/processed/ces/2011_spatial_deflators.dta"
					
	Inputs 2022		: "${user}/data/processed/ces/master_consumption_wy_2022${s}.dta"
					  "${user}/data/processed/ces/master_item_list_2022.dta"
					  "${user}/data/processed/ces/master_hh_2022.dta"
					  "${user}/data/processed/ces/2022_spatial_deflators${s}.dta"
					  "${user}/data/processed/ces/515_total_hhexp.dta"
					
	Outputs			: "${user}/data/processed/ces/mpce_2011${s}.dta"
					  "${user}/data/processed/ces/mpce_2022${s}.dta"
					  "${user}/data/processed/ces/welfare_agg_2011${s}.dta"
					  "${user}/data/processed/ces/welfare_agg_2022${s}.dta"
								
	Steps for each survey year: 	
		*1. Start from master_consumption. Drop subtotals, merge master_hh & item_list to retrieve vars.
		*2. Ajust consumption value to 30days.
		*3. Collapse from item level to commodity group level.
		*4. Reshape to create balanced panel. Each HH should have 25 commodity groups.
		*5. Calculate nominal and temporally deflated MPCE. Check whether nominal MPCE matches report.
		*6. Calculate share of other commodity groups (except 15 CGs) in nominal expenditure. 
		*7. Merge to get spatial deflators and normalise to 1 at HH level. 
		*8. Adjust constructed MPCE (step 7) to add back the share of other commodity groups. 
		*9. Collapse at HH level to create MPCEs: nominal, temporally adjusted, temporal+spatial adjusted.
		
		* Final step is to apply inter-temporal deflation and save the welfare aggregate 
		in 2017 prices for both years in each scenario 		
	============================================================================= */

	* Define macros & scalars
	glo cpi_2011 = 113.606952605421    //avg monthly cpi survey year (Jul-11 to June-12) IFS
	glo cpi_2017 = 159.181198120117    //avg monthly cpi calendar year (jan-17 to dec-17)  IFS
	glo cpi_2022 =  211.9832504895     //avg monthly cpi survey year (Aug-22 to July-23) IFS
	glo svy_yr 2011 2022
	
	*===============================================================================
		*SECTION A. 2011 MPCE construction
	*===============================================================================

	* Step 1. From master_consumption. Drop subtotals, merge master_hh & item_list to retrieve vars.
	use "${user}/data/processed/ces/master_consumption_wy_2011${s}.dta", clear
	merge m:1 hhid using "${user}/data/processed/ces/master_hh_2011.dta", keepusing(hhsize state sector district pwt)
	drop _m
	merge m:1 item  using "${user}/data/processed/ces/master_item_list_2011.dta", keepusing(subtotal commodity_group recall_period )
	drop _m
		
	* Drop subtotals
	drop if subtotal==1 
	
	*Step 2. Ajust consumption value to 30days.
	g double value_adj${s} 			= value_total${s} 			if recall_period==30
		replace value_adj${s} 		= value_total${s}*(30/7) 	if recall_period==7
		replace value_adj${s} 		= value_total${s}*(30/365) 	if recall_period==365
	
	g double value_def_adj${s} 		= value_deflated${s} 		if recall_period==30
		replace value_def_adj${s} 	= value_deflated${s}*(30/7) 	if recall_period==7
		replace value_def_adj${s} 	= value_deflated${s}*(30/365) 	if recall_period==365

	*Step 3. Collapse from item level to commodity group level.
	collapse (sum) value_adj${s} value_def_adj${s} (mean) pwt hhsize, by(hhid state sector district commodity_group)
	
	*Step 4. Reshape to create balanced panel. Each HH should have 25 commodity groups.
	fastreshape wide value_adj${s} value_def_adj${s}, i(hhid) j(commodity_group)
	fastreshape long value_adj${s} value_def_adj${s}, i(hhid) j(commodity_group)
	
	*Step 5. Expenditures at CG level. Calculate nominal and temporally deflated MPCE. Check whether nominal MPCE matches report.
	g double exp_nom 	= value_adj${s}/hhsize
	g double exp_wy_def = value_def_adj${s}/hhsize	
	bys hhid : egen double mpce_nom = total(exp_nom)		// MPCE #1 
	bys hhid : egen double mpce_wy_def = total(exp_wy_def)	// MPCE #2
	
	lab var mpce_nom 			"MPCE - nominal"
	lab var mpce_wy_def 		"MPCE - inter-temporally deflated"

	/* CHECK
		table state sector [aw=pwt], stat(mean mpce_nom) 
		table state sector [aw=pwt], stat(mean mpce_wy_def) */	

	*Step 6. Calculate share of other commodity groups (except 15 CGs) in nominal expenditure. 
	g sp_dum = inrange(commodity_group, 1, 15)
	lab var sp_dum 			"Indicator for CG in spatial deflators"
	
	bys hhid : egen double exp_other = total(exp_nom) if sp_dum==0
	g double sh_other = exp_other/mpce_nom
	lab var sh_other 		"Expenditure share of remaining commodity groups"
		
	*Step 7.  Merge to get spatial deflators and normalise to 1 at HH level. 

	merge m:1 state sector commodity_group using "${user}/data/processed/ces/2011_spatial_deflators.dta", keepusing(sp_def_sec_2011 sp_def_ind_2011) nogen
	
	* deflate at CG level
	g double exp_def_temp_sec = exp_wy_def/sp_def_sec_2011		
	g double exp_def_temp_ind = exp_wy_def/sp_def_ind_2011

	bys hhid : egen double cg15_agg_wy_def = total(exp_wy_def) if sp_dum==1
	lab var cg15_agg_wy_def "Agg for 15CG - inter-temporally deflated"

	bys hhid: egen double cg15_sp_def_sec = total(exp_def_temp_sec) if sp_dum==1
	bys hhid: egen double cg15_sp_def_ind = total(exp_def_temp_ind) if sp_dum==1
	 
	g double implicit_sp_def_sec 		= cg15_agg_wy_def/cg15_sp_def_sec
	g double implicit_sp_def_ind 		= cg15_agg_wy_def/cg15_sp_def_ind
	bys sector: egen double sp_def_sec	= wmean(implicit_sp_def_sec), weights(pwt)
	g double sp_rel_sec 				= implicit_sp_def_sec/sp_def_sec
	
	tabstat sp_rel_sec [aw=pwt], by(sector) //check should add to 1
	
	lab var implicit_sp_def_sec "Spatial deflator at sector (unadj)"
	lab var sp_rel_sec 			"Spatial deflator relative to sector"
	
	egen double sp_def_ind 	= wmean(implicit_sp_def_ind), weights(pwt)
	g double sp_rel_ind 	= implicit_sp_def_ind/sp_def_ind
	
	tabstat sp_rel_ind [aw=pwt] //check should add to 1
	
	lab var implicit_sp_def_ind "Spatial deflator at India (unadj)"
	lab var sp_rel_ind 			"Spatial deflator relative to India"
	
	g double exp_sp_15_sec 					= exp_wy_def/sp_rel_sec	if sp_dum==1
	g double exp_sp_15_ind 					= exp_wy_def/sp_rel_ind	if sp_dum==1
	bys hhid : egen double mpce_sp_15_sec 	= total(exp_sp_15_sec)
	bys hhid : egen double mpce_sp_15_ind 	= total(exp_sp_15_ind)
	
	lab var mpce_sp_15_sec "MPCE - spatially adjusted for 15 commodity groups - All India-Sector base"
	lab var mpce_sp_15_ind "MPCE - spatially adjusted for 15 commodity groups - All India base"
			
	*Step 8. Adjust constructed MPCE (step 7) to add back the share of other commodity groups. 
	g double mpce_sp_def_sec = mpce_sp_15_sec / (1-sh_other)		// MPCE # 3
	g double mpce_sp_def_ind = mpce_sp_15_ind / (1-sh_other)		// MPCE # 4

	lab var mpce_sp_def_sec "MPCE - spatially adjusted - AllIndia-Sector base"
	lab var mpce_sp_def_ind "MPCE - spatially adjusted - allIndia base"
		
	*Step 9. Collapse at HH level to create MPCEs.
	collapse (mean) mpce_nom mpce_wy_def mpce_sp_def_sec mpce_sp_def_ind implicit_sp_def_sec implicit_sp_def_ind sp_rel_sec sp_rel_ind  pwt, by(hhid hhsize state sector)
	g year=2011
	
	lab var mpce_nom 			"MPCE - nominal"								// MPCE #1
	lab var mpce_wy_def 		"MPCE - inter-temporally deflated"				// MPCE #2
	lab var mpce_sp_def_sec 	"MPCE - spatially adjusted - AllIndia-Sector base"	// MPCE #3
	lab var mpce_sp_def_ind  	"MPCE - spatially adjusted - AllIndia base"			// MPCE #4
	lab var implicit_sp_def_sec "Spatial deflator at sector (unadj)"
	lab var implicit_sp_def_ind "Spatial deflator at India (unadj)"
	lab var sp_rel_sec 			"Spatial deflator relative to sector"
	lab var sp_rel_ind 			"Spatial deflator relative to India"
	lab var pwt 				"Survey population weights"
	
	table state sector [aw=pwt], stat(mean mpce_nom)
	save "${user}/data/processed/ces/mpce_2011${s}.dta", replace 

	*===============================================================================
		*SECTION B. 2022 MPCE construction
	*===============================================================================

	* Step 1. From master_consumption. Drop subtotals, merge master_hh & item_list to retrieve vars.
	use "${user}/data/processed/ces/master_consumption_wy_2022${s}.dta", clear
	merge m:1 hhid using "${user}/data/processed/ces/master_hh_2022.dta", keepusing(pwt state sector stratum district)
	drop _m
	merge m:1 item  using "${user}/data/processed/ces/master_item_list_2022.dta", keepusing(subtotal sub_grains commodity_group survey_type recall_period agg_item)
	drop _m
	
	
	* Drop subtotals
	drop if subtotal==1  | sub_grains ==1
	drop if agg_item==1
	
	* Specific complexity in 2022 with multiple hhsizes (for each questionaire)
		preserve
		use "${user}/data/processed/ces/level15_2022.dta", clear
			keep hhid hhsize section_new hhwt
			fre section_new
			drop if section_new==1 //dropping HCQ
		reshape wide hhsize, i(hhid) j(section_new)
		la var hhsize2 "HHsize from FDQ"
		la var hhsize3 "HHsize from CSQ"
		la var hhsize4 "HHsize from DGQ"
			
		tempfile hhsize_adjust
		save `hhsize_adjust'
		restore
	
		merge m:1 hhid using `hhsize_adjust', keep(3) nogen
		
		g double value_adj1 	= value_total${s} 		if survey_type==1 
			replace value_adj1 	= value_total${s} *(hhsize2/hhsize3) if survey_type==2
			replace value_adj1 	= value_total${s} *(hhsize2/hhsize4) if survey_type==3
		
		g double value_def1 	= value_deflated${s} if survey_type==1  
			replace value_def1 	= value_deflated${s} *(hhsize2/hhsize3) if survey_type==2 
			replace value_def1 	= value_deflated${s} *(hhsize2/hhsize4) if survey_type==3
		
	*Step 2. Ajust consumption value to 30days.
	g double value_adj 		= value_adj1 			if recall_period==30
		replace value_adj 	= value_adj1*(30/7)	 	if recall_period==7
		replace value_adj 	= value_adj1*(30/365) 	if recall_period==365
	
	g double value_def_adj 		= value_def1 			if recall_period==30
		replace value_def_adj 	= value_def1*(30/7) 	if recall_period==7
		replace value_def_adj 	= value_def1*(30/365) 	if recall_period==365
	
		drop value_adj1 value_def1 hhsize3 hhsize4 
		
		ren hhsize2 hhsize

	*Step 3. Collapse from item level to commodity group level.
	collapse (sum) value_adj value_def_adj (mean) pwt hhsize, by(hhid state sector stratum commodity_group)
	
	*Step 4. Reshape to create balanced panel. Each HH should have 25 commodity groups.
	fastreshape wide value_adj value_def_adj , i(hhid) j(commodity_group)
	fastreshape long value_adj value_def_adj , i(hhid) j(commodity_group)
	
	*Step 5. Calculate nominal and temporally deflated MPCE. Check whether nominal MPCE matches report.
	g double exp_nom 	= value_adj/hhsize
	g double exp_wy_def = value_def_adj/hhsize
	
	bys hhid : egen double mpce_nom 	= total(exp_nom)			// MPCE #1
	bys hhid : egen double mpce_wy_def 	= total(exp_wy_def)		// MPCE #2
	
	la var mpce_nom 	"MPCE - nominal "
	la var mpce_wy_def 	"MPCE - inter-temporally deflated "

	/* CHECK
		table state sector [aw=pwt], stat(mean mpce_nom) 
		table state sector [aw=pwt], stat(mean mpce_wy_def) 	*/	
	
	*Step 6. Calculate share of other commodity groups (except 15 CGs) in nominal expenditure. 
	g sp_dum = inrange(commodity_group, 1, 15)
	lab var sp_dum "Indicator for CG in spatial deflators"
	
	bys hhid : egen double exp_other = total(exp_nom) if sp_dum==0
	g double sh_other = exp_other/mpce_nom
	lab var sh_other "Expenditure share of remaining commodity groups"
	
	*Step 7. Merge to get spatial deflators and normalise to 1 at HH level. 

	merge m:1 state sector commodity_group using "${user}/data/processed/ces/2022_spatial_deflators.dta", keepusing(sp_def_sec_2022 sp_def_ind_2022) nogen
	
	* Deflate at CG level
	g double exp_def_temp_sec = exp_wy_def/sp_def_sec_2022		
	g double exp_def_temp_ind = exp_wy_def/sp_def_ind_2022

	bys hhid : egen double cg15_agg_wy_def = total(exp_wy_def) if sp_dum==1
	lab var cg15_agg_wy_def 	"Agg for 15CG - inter-temporally deflated"
	bys hhid: egen double cg15_sp_def_sec = total(exp_def_temp_sec) if sp_dum==1
	bys hhid: egen double cg15_sp_def_ind = total(exp_def_temp_ind) if sp_dum==1
	 
	g double implicit_sp_def_sec = cg15_agg_wy_def/cg15_sp_def_sec
	g double implicit_sp_def_ind = cg15_agg_wy_def/cg15_sp_def_ind
	
	bys sector: egen double sp_def_sec= wmean(implicit_sp_def_sec), weights(pwt)
	g double sp_rel_sec = implicit_sp_def_sec/sp_def_sec
	
	tabstat sp_rel_sec [aw=pwt], by(sector) //check should add to 1
	
	lab var implicit_sp_def_sec 	"Spatial deflator at sector (unadj)"
	lab var sp_rel_sec 				"Spatial deflator relative to sector"
	
	egen double sp_def_ind = wmean(implicit_sp_def_ind), weights(pwt)
	g double  sp_rel_ind = implicit_sp_def_ind/sp_def_ind
	
	tabstat sp_rel_ind [aw=pwt] //check should add to 1
	
	lab var implicit_sp_def_ind 	"Spatial deflator at India (unadj)"
	lab var sp_rel_ind 				"Spatial deflator relative to India"
	
	g double exp_sp_15_sec = exp_wy_def/sp_rel_sec	if sp_dum==1
	g double exp_sp_15_ind = exp_wy_def/sp_rel_ind	if sp_dum==1
	bys hhid : egen double mpce_sp_15_sec = total(exp_sp_15_sec)
	bys hhid : egen double mpce_sp_15_ind = total(exp_sp_15_ind)
	
	lab var mpce_sp_15_sec "MPCE - spatially adjusted for 15 commodity groups - All India-Sector base "
	lab var mpce_sp_15_ind "MPCE - spatially adjusted for 15 commodity groups - All India base "
		
	*Step 8. Adjust constructed MPCE (step 7) to add back the share of other commodity groups. 
	g double mpce_sp_def_sec = mpce_sp_15_sec / (1-sh_other)
	g double mpce_sp_def_ind = mpce_sp_15_ind / (1-sh_other)
	la var mpce_sp_def_sec "MPCE - spatially adjusted - AllIndia-Sector base"	// MPCE #3
	la var mpce_sp_def_ind "MPCE - spatially adjusted - AllIndia base"			// MPE #4
	
	*Step 9 
	collapse (mean) mpce_nom mpce_wy_def mpce_sp_def_sec mpce_sp_def_ind ///
		implicit_sp_def_sec implicit_sp_def_ind sp_rel_sec sp_rel_ind ///
		pwt, by(hhid hhsize state sector stratum)
	
	g year=2022
	
	la var mpce_nom 			"MPCE - nominal "									// MPCE #1
	la var mpce_wy_def 			"MPCE - inter-temporally deflated "					// MPCE #2
	la var mpce_sp_def_sec 		"MPCE - spatially adjusted - AllIndia-Sector base"	// MPCE #3
	la var mpce_sp_def_ind  	"MPCE - spatially adjusted - AllIndia base"			// MPE #4
	la var implicit_sp_def_sec 	"Spatial deflator at sector (unadj)"
	la var implicit_sp_def_ind 	"Spatial deflator at India (unadj)"
	la var sp_rel_sec 			"Spatial deflator relative to sector"
	la var sp_rel_ind 			"Spatial deflator relative to India"
	la var pwt 					"Survey population weights"
	
	table state sector [aw=pwt] if stratum!="99", stat(mean mpce_nom)
	
	save "${user}/data/processed/ces/mpce_2022${s}.dta", replace

	*===============================================================================
		*SECTION C. Construct welfare aggregate in 2017 prices (for both 2011 & 2022)
	*===============================================================================		

	use "${user}/data/processed/ces/mpce_2011${s}.dta", clear
	append using "${user}/data/processed/ces/mpce_2022${s}.dta"

	drop if mi(hhid)
	
	g double welfare_agg17_nom 	= .
	g double welfare_agg17_wy 	= .
	g double welfare_agg17_sp 	= .
		
	foreach v of glo svy_yr {
		replace welfare_agg17_nom = mpce_nom 	* (${cpi_2017}/${cpi_`v'}) 	if year ==`v'
		replace welfare_agg17_wy = mpce_wy_def 	* (${cpi_2017}/${cpi_`v'}) 	if year ==`v'
		replace welfare_agg17_sp = mpce_sp_def_ind * (${cpi_2017}/${cpi_`v'}) if year ==`v' // Use All-India sector 
		}
		
	keep hhid hhsize state sector year welfare_agg17* pwt 
	drop if mi(state)
	
	lab var year "Survey year"
	lab var welfare_agg17_nom "Welfare aggregate in scenario ${s} - 2017 prices"
	lab var welfare_agg17_wy "Intra-temporal deflated welfare aggregate in scenario ${s} - 2017 prices"
	lab var welfare_agg17_sp "Temporal and spatially deflated welfare aggregate in scenario ${s} - 2017 prices" 
	
	gen scenario = "{$s}"
	
	save "${user}/data/processed/ces/welfare_agg_17${s}.dta", replace 
	
	* =============================================================================*
		di in red "THE END OF 06_welfare_agg${s}" 
	* =============================================================================*
	cap log close
	exit