
	loc date: display %tdCCYY-NN-DD =daily("`c(current_date)'", "DMY")
	cap log close
	log using "${user}/output/log/07_pov_ineq_`date'", replace

	/* =============================================================================
		Project			: India poverty estimates - 2011-12 & 2022-23 
		Dofile			: 07_pov_ineq.do
		Last modified	: 26th March 2025

		Inputs			: "${user}/data/processed/ces/welfare_agg_17_all"
						
		Outputs			: "${user}/output/welfare_pov_final"

		Steps			: 01. Construct 2017 PPP poverty lines, in 2017 PPP
						  02. Calculate poverty rates under different poverty lines and PPPs
						  03. Calculate gini coefficient				
	================================================================================ */

	* Define macros & scalars
			glo 	povlines17 	215 365 685 
			scalar	ppp17	= 	19.46903992    // https://databank.worldbank.org/source/icp-2017#

	*Delete heavy intermediate files
	erase "${user}/data/processed/ces/master_consumption_2011_pds.dta" 
	erase "${user}/data/processed/ces/master_consumption_2011_lumpexp.dta" 	
	erase "${user}/data/processed/ces/master_consumption_2011_hosp.dta" 		
	erase "${user}/data/processed/ces/master_consumption_2011_rent.dta" 
	erase "${user}/data/processed/ces/master_consumption_wy_2011_pds.dta"
	erase "${user}/data/processed/ces/master_consumption_wy_2011_lumpexp.dta"
	erase "${user}/data/processed/ces/master_consumption_wy_2011_hosp.dta"
	erase "${user}/data/processed/ces/master_consumption_wy_2011_rent.dta"

	erase "${user}/data/processed/ces/master_consumption_2022_pds.dta" 
	erase "${user}/data/processed/ces/master_consumption_2022_lumpexp.dta" 	
	erase "${user}/data/processed/ces/master_consumption_2022_hosp.dta" 		
	erase "${user}/data/processed/ces/master_consumption_2022_rent.dta" 
	erase "${user}/data/processed/ces/master_consumption_wy_2022_pds.dta"
	erase "${user}/data/processed/ces/master_consumption_wy_2022_lumpexp.dta"
	erase "${user}/data/processed/ces/master_consumption_wy_2022_hosp.dta"
	erase "${user}/data/processed/ces/master_consumption_wy_2022_rent.dta"


	*Delete files in "temp" subfolder
	local datafiles1: dir "${user}/data/processed/ces/temp" files "*.dta"
	foreach datafile of local datafiles1 {
		erase "${user}/data/processed/ces/temp/`datafile'"
	}

	*Delete files in sensitivity checks subfolders
	local datafiles2: dir "${user}/data/processed/ces/sensitivity_checks/outliers" files "*.dta"
	foreach datafile of local datafiles2 {
		erase "${user}/data/processed/ces/sensitivity_checks/outliers/`datafile'"
	}

	local datafiles3: dir "${user}/data/processed/ces/sensitivity_checks/inter_temporal" files "*.dta"
	foreach datafile of local datafiles3 {
		erase "${user}/data/processed/ces/sensitivity_checks/inter_temporal/`datafile'"
	}

	local datafiles4: dir "${user}/data/processed/ces/sensitivity_checks/hhsize" files "*.dta"
	foreach datafile of local datafiles4 {
		erase "${user}/data/processed/ces/sensitivity_checks/hhsize/`datafile'"
	}

	local datafiles5: dir "${user}/data/processed/ces/sensitivity_checks/add_housing" files "*.dta"
	foreach datafile of local datafiles5 {
		erase "${user}/data/processed/ces/sensitivity_checks/add_housing/`datafile'"
	}




	* Use the welfare aggregate created for the final "ALL" scenario

	use "${user}/data/processed/ces/welfare_agg_17_all.dta", clear
		
	*===============================================================================
	*Step 1. Construct 2017 poverty lines, expressed in INR 2017 PPP
	*===============================================================================

	foreach i of glo povlines17 {
		gen double pline_`i'= (`i'/100)*(365/12)*ppp17
		}
			
	*===============================================================================
	*Step 2. Calculate dummies for poor households
	*===============================================================================

	foreach i of glo povlines17 {
		gen double poor_`i'  	= .
		replace poor_`i' 	= welfare_agg17_sp  <= pline_`i' 
		}	

	keep hhid sector pwt year poor_* welfare_agg17_sp hhsize
		
	*lab def sector 1 "Rural" 2 "Urban"
	*lab val sector sector
	lab var poor_215 "Poverty dummy - below $2.15"
	lab var poor_365 "Poverty dummy - below $3.65"
	lab var poor_685 "Poverty dummy - below $6.85"
	
	gen poor_215_perc = poor_215*100
	gen poor_365_perc = poor_365*100
	gen poor_685_perc = poor_685*100
		
	di in red "Poverty rates under $2.15"
	table sector year [aw=pwt], stat(mean poor_215_perc) totals(year) nformat(%9.1f) sformat("%s%%") 

	di in red "Poverty rates under $3.65"
	table sector year [aw=pwt], stat(mean poor_365_perc) totals(year) nformat(%9.1f) sformat("%s%%") 


	di in red "Poverty rates under $6.85"
	table sector year [aw=pwt], stat(mean poor_685_perc) totals(year) nformat(%9.1f) sformat("%s%%") 	

	save "${user}/output/welfare_pov_final.dta", replace
	
	*===============================================================================
	*Step 3. Calculate Gini coefficient
	*===============================================================================

	*All-India, rural and urban gini - define and store results in matrix
	mat drop _all
	foreach y of numlist 2011 2022 {		
			mat define gini_`y' = J(1, 3, .)
			mat rownames gini_`y' = `y'
			mat colnames gini_`y' = rural urban national
	foreach i of numlist 1 2 {
		ainequal welfare_agg17_sp  [aw=pwt] if sector==`i' & year==`y'
		mat gini_`y' [1,`i'] = `r(gini_1)'		
	}
	ainequal welfare_agg17_sp  [aw=pwt] if year==`y'
	mat gini_`y' [1,3] = `r(gini_1)'
	}
	
	*Matrix combine
	mat define gini = J(2,3,.)
	mat gini = gini_2011 \ gini_2022
	
	mat gini_index = 100 * gini
	
	mat list gini_index, format(%9.1f)

				
* =============================================================================*
	di in red "THE END OF 07_pov_ineq" 
* =============================================================================*
	cap log close
	exit
