
	loc date: display %tdCCYY-NN-DD =daily("`c(current_date)'", "DMY")
	cap log close
	log using "${user}/output/sensitivity_checks/add_housing/log/02a_housing_2022_prematch_`date'.log", replace

	/* =============================================================================
	Project			: India poverty estimates - 2011-12 & 2022-23 
	Dofile			: 02d_housing_2022
	Last modified	: April 11th 2025

	Inputs			: "${user}/data/processed/ces/master_consumption_2022.dta"
					  "${user}/data/processed/ces/master_hh_2022.dta"
					  "${user}/data/processed/ces/master_item_list_2022.dta"
					  "${user}/data/processed/ces/mpce_2022.dta"
					  "${user}/data/processed/ces/level03_2022.dta"
					  "${user}/data/processed/ces/level07_2022dta"
					  "${user}/data/processed/ces/level11_2022.dta"
																					
	Output			:  "${user}/data/processed/ces/sensitivity_checks/add_housing/rents_hh_2022_prematch.dta"
					  
	*Steps			:  *1. Retrieve rental values and nominal MPCE, 2022 
					   *2. Bring in raw datasets with dwelling characteristics, 2022
					   *3. Create variables for hedonic model, 2022
					   
	============================================================================ */
			
	*===============================================================================
	* 1. Retrieve rental values and nominal MPCE for 2022 
	*===============================================================================

		*1.1) Retrieve master datasets
		use "${user}/data/processed/ces/master_consumption_2022.dta", clear
		merge m:1 hhid using "${user}/data/processed/ces/master_hh_2022.dta", keepusing(pwt state sector stratum district) nogen
		merge m:1 item  using "${user}/data/processed/ces/master_item_list_2022.dta", keepusing(subtotal sub_grains commodity_group survey_type recall_period agg_item) nogen
			
		*1.2) Keep rents at the HH level because rent_imputed (item 539) has a special treatment (flagged as agg_item==1 and dropped)
			g rent_actual = 0
				replace rent_actual  = value_total if item == 520
			g rent_imputed = 0
				replace rent_imputed = value_total if item == 539	
				collapse (sum) rent_actual rent_imputed (max) survey_month, by(hhid)
			tempfile rents_temp
			save `rents_temp'
		
		*1.3) Retrieve aggregates & create q20	
		use "${user}/data/processed/ces/mpce_2022.dta", clear // Baseline scenario without adjustments
			g mpce_q20 =.
					forval i=1/2{
					xtile mpce_q20_`i' = mpce_nom [w=pwt] if sector==`i', nq(20)
					replace mpce_q20=mpce_q20_`i' if sector==`i'
					}
			
			lab var mpce_q20 "Vigintile of nominal expenditures pc, by sector"
			merge 1:1 hhid using `rents_temp', keep(3)
			drop _m mpce_q20_*
					
	*===============================================================================
	*2. Bring in datasets with dwelling characteristics for 2022
	*===============================================================================

		*2.1) Merge with additional HH characteristics
		tostring year, replace
		merge 1:1 hhid using "${user}/data/processed/ces/level03_2022.dta", keep(3) nogen
			
		*2.2) Merge with internet data
		merge 1:1 hhid using "${user}/data/processed/ces/level07_2022.dta", keepusing(internet_hh) keep(3) nogen
				
		*2.3) Merge with assets information	
		merge 1:1 hhid using "${user}/data/processed/ces/level11_2022.dta", keepusing(television laptop air_conditioner car refrigerator washing_machine mobile) keep(3) nogen

	*===============================================================================
	*3. Create variables for hedonic model 
	*===============================================================================

		*3.1) Assign typeof_dwelling=others for HHs claiming rent_actual or rent_imputed but missing value in typeof_dwelling
		replace typeof_dwelling=3 if typeof_dwelling==. & ((rent_actual>0 & rent_actual<.) | (rent_imputed>0 & rent_imputed<.))	
		
		*3.2) Fix "owners" that claim rental values = 1
		replace rent_actual 	= 0 if typeof_dwelling==1 & rent_actual==1	
		replace rent_imputed 	= 0 if typeof_dwelling==1 & rent_imputed==1	
		
		*3.3) Create rent variable (actual for renters, imputed for owners and others)
		g double rent = 0 
			replace rent = rent_actual 	if typeof_dwelling==2
			replace rent = rent_imputed if typeof_dwelling==1 | typeof_dwelling==3 
			lab var rent "Rent (HH level): actual for renters, self-imputed for owners/others"
		
		*3.4) Winsorize rent variable at 1% on each tail (given a type of dwelling)
		winsor2 rent, cuts(1 99) suff(_w1) by(typeof_dwelling sector) 
			
		*3.5) Log of winzorized rents
		g l_rent=log(rent_w1)
		
		*3.6) Size/area
		replace area_owned=0.00001 if area_owned==0
		g log_area = log(area_owned)
		
		*3.7) Log of household size
		g l_hhsize = log(hhsize)
			
		*3.8) Lighting
		destring lighting, replace
		g electricity = 0
			replace electricity=1 if lighting==1
				
		*3.9) Mobile
		ren mobile mobile_orig
		g mobile = 0
			replace mobile = 1 if mobile_orig==1
		drop mobile_orig
			
		*3.10) Internet
		g internet = 0
			replace internet=1 if internet_hh==1
				
		*3.11) Time to water
		destring time_taken_water, replace // in minutes
		replace time_taken_water=0.01 if time_taken_water==0
		g log_time_to_water = log(time_taken_water)

		*3.12) Assets
		replace television 		= 0 if television == .
		replace laptop 			= 0 if laptop ==.
		replace air_conditioner = 0 if air_conditioner == .
		replace car 			= 0 if car == .
		replace refrigerator 	= 0 if refrigerator == .
		replace washing_machine = 0 if washing_machine == .
		
		label define assets_lbl 1 "Yes" 0 "No"
		label values television assets_lbl
		label values laptop assets_lbl
		label values air_conditioner assets_lbl
		label values car assets_lbl
		label values refrigerator assets_lbl
		label values washing_machine assets_lbl
			
		*3.13) Income source (24.815 obs with missing value ~ 10% of dataset)
		g nic_agro = 0
			replace nic_agro = 1 if inrange(substr(nic_code, 1, 2), "01", "03")
		g nic_industry = 0
			replace nic_industry = 1 if inrange(substr(nic_code, 1, 2), "05", "43")
		g nic_services = 0
			replace nic_services = 1 if inrange(substr(nic_code, 1, 2), "45", "83")
			replace nic_services = 1 if inrange(substr(nic_code, 1, 2), "85", "99")
		g nic_public = 0
			replace nic_public = 1 if substr(nic_code, 1, 2) == "84"

		*3.14) Religion
		g hindu = 0
			replace hindu = 1 if religion==1

		*3.15) Renter
		g renter = (typeof_dwelling == 2 & rent_actual > 0 & rent_actual<.)
		
		*3.16) Dwelling characteristics (categorical variables)
		replace wall_material  = 99 if wall_material  == . // No response (13 hh)
		replace floor_material = 99 if floor_material == . // No response (13 hh)
		replace roof_material  = 99 if  roof_material == . // No response (13 hh)
		replace drinking_water = 99 if drinking_water == . // No response (0 hh)
		replace latrine_type   = 99 if latrine_type   == . // No response (26.190 hh)
		replace cooking        = 99 if cooking        == . // No response (0 hh)
		replace caste          = 99 if caste          == . // No response (0 hh)

				
		lab var log_area 		  "Log(total area of dwelling)"
		lab var mobile 			  "Dwelling has mobile telephone"
		lab var internet 		  "Dwelling has internet"
		lab var television		  "Dwelling has a television"	
		lab var laptop			  "Dwelling has a laptop"	
		lab var air_conditioner	  "Dwelling has an air conditioner"	
		lab var car				  "Dwelling has a car"	
		lab var refrigerator	  "Dwelling has a refrigerator"	
		lab var washing_machine	  "Dwelling has a washing machine"	
		lab var log_time_to_water "Log(time to water)"	
		lab var nic_agro    	  "NIC-20008: Agro"
		lab var nic_industry	  "NIC-20008: Industry"
		lab var nic_services	  "NIC-20008: Services"
		lab var nic_public		  "NIC-20008: Public"
		lab var hindu			  "Religion is Hindu"
		lab var l_hhsize		  "log(household size)"
		lab var rent_actual 	  "Home rents"
		lab var rent_imputed 	  "Imputed rents"
		lab var rent			  "Home rents for renters, imputed rents for owners and others"
		lab var l_rent			  "Logs of home rents for renters, imputed rents for owners and others per capita (winsorized 1%)"

		save "${user}/data/processed/ces/sensitivity_checks/add_housing/rents_hh_2022_prematch.dta", replace	
		*This file is the input of the R-script for the matching exercise.

	*===============================================================================
	di in red "THE END OF 02a_housing_prematch"
	*===============================================================================
	log close
	exit
	