
	loc date: display %tdCCYY-NN-DD =daily("`c(current_date)'", "DMY")
	cap log close
	log using "${user}/output/log/04_outliers_deflators_wy${zs}_`date'", replace
			
	/* =============================================================================
		Project			: India Poverty Estimates 
		Dofile			: 04_outliers_deflators_wy${zs}
		Last modified	: 21 Jan 2025


		Inputs			:	"${user}/data/processed/ces/master_consumption_wy_2011_all.dta"
							"${user}/data/processed/ces/master_hh_2011.dta"
							"${user}/data/processed/ces/master_item_list_2011.dta"
		
		Output			:	"${user}/output/sensitivity_checks/outliers/${zs}.xlsx"
							"${user}/data/processed/ces/sensitivity_checks/outliers/flags_2011${zs}"
							${user}/data/processed/ces/sensitivity_checks/outliers/flags_2022${zs}"
							"${user}/data/processed/ces/sensitivity_checks/outliers/master_consumption_wy_2011${zs}.dta"
							"${user}/data/processed/ces/sensitivity_checks/outliers/master_consumption_wy_2011${zs}.dta"
	============================================================================= */

	*===============================================================================
		*1. OUTLIERS flagging
	*===============================================================================

	
	* Define cut-offs for outlier checks	
	if strpos("$zs", "out3_all") > 0 {
		glo zi 3		// using 3sd
		di in red "cut-off $zi-sd"
	}
	
	if strpos("$zs", "out4_all") > 0 {
		glo zi 4	// using 4sd
		di in red "cut-off $zi-sd"
	}
	

	foreach j of numlist 2011 2022 {
	
		use "${user}/data/processed/ces/master_consumption_wy_`j'_all.dta", clear 
		merge m:1 hhid using "${user}/data/processed/ces/master_hh_`j'.dta", keepusing(state sector district sss hhsize hhwt) keep(3) nogen	
		gen pwt = hhsize*hhwt
		
		*Drop subtotals, items with no quantity, and non-food items			
		if `j' ==2011 {
		merge m:1 item using "${user}/data/processed/ces/master_item_list_`j'.dta", keepusing(recall_period commodity_group unit subtotal pds no_qty item_desc) keep(3) nogen

			drop if subtotal==1
			drop if no_qty==1
			
			drop if item>=300 //keep only food items with unit values
	
		*Keep observations that have purchased from the market 
			keep if source==1
			ta item if missing(unit) //should be zero
		
		*Drop households not consuming the item
			drop if inlist(value_total, 0, .)
			drop if inlist(qty_total, 0, .)
			}
		
		*Drop subtotals, items with no quantity, and non-food items			
		if `j'== 2022 {
		merge m:1 item using "${user}/data/processed/ces/master_item_list_`j'.dta", keepusing(recall_period commodity_group unit subtotal pds no_qty free item_desc survey_type item_139) keep(3) nogen
			
			drop if subtotal==1
			drop if free==1
			drop if no_qty==1
			keep if survey_type==1 //keep only food items with unit values

		*Keep observations that have purchased from the market 
			keep if source==1
			ta item if missing(unit) //should be zero
			
		*Drop households not consuming the item
			drop if inlist(value_total, 0, .)
			drop if inlist(qty_total, 0, .)
		 }
		 
		*Generate unit value after adjusting for within-year price variations
		gen uv_def = value_deflated_all /qty_new
		gen log_uv_def = ln(uv_def)
		
		*Calculate quantity per capita
		gen qty_pc = qty_new/hhsize
		
		*Calculate log mean, standard deviation and z-score
		preserve
		collapse (mean) mean_log_uv_def = log_uv_def (sd) sd_log_uv_def = log_uv_def [aw=pwt], by(state sector item sss) 
		tempfile descriptives
		save `descriptives', replace
		restore
		
		merge m:1 state sector item sss using `descriptives', keep(3) nogen
		
		gen z_uv_def = (log_uv_def - mean_log_uv_def) / sd_log_uv_def
				
		*Flag outliers higher than 3 SD and 4 SD
			gen out_${zi}_uv_def = 1 if abs(z) >= ${zi} & z_uv_def!=.
			replace out_${zi}_uv_def  = 0 if missing(out_${zi}_uv_def )
			table item_desc out_${zi}_uv_def
			*collect export "${output}/sensitivity_checks/outliers/excel/${zs}.xlsx", sheet("outliers_num_`j'", replace) modify
		
		*Saving outliers flagged
		save "${user}/data/processed/ces/sensitivity_checks/outliers/flags_`j'${zs}", replace
	}
		
	*===============================================================================
		*2. Calculating median prices
	*===============================================================================
		 	
	foreach j of numlist 2011 2022 {
		
		*Merge outliers flag to master consumption
		use "${user}/data/processed/ces//master_consumption_wy_`j'_all.dta", clear 
		merge m:1 hhid using "${user}/data/processed/ces/master_hh_`j'.dta", keepusing(state sector district sss hhsize hhwt) keep(3) nogen	
		merge m:1 item using "${user}/data/processed/ces/master_item_list_`j'.dta", keepusing(unit) keep(3) nogen
		merge 1:1 hhid item using "${user}/data/processed/ces/sensitivity_checks/outliers/flags_`j'${zs}", keepusing(out_${zi}_uv_def uv_def)
		drop _m

		gen pwt = hhwt*hhsize
		
		*Define hierarchial model for calculating median prices
		local level1 = "state sector sss item"
		local level2 = "state sector item"
		local level3 = "state item"
		local level4 = "sector item"
		local level5 = "item"
		
		*Calculate median price using non-outliers data at each of the five levels
		forval k = 1/5 {
			preserve					
					keep if out_${zi}_uv_def==0			
					collapse (median) med_`k'_${zi} = uv_def (count) count_`k'_${zi} = uv_def [aw=pwt], by(`level`k'')
					tempfile m_`k'_${zi}
					save `m_`k'_${zi}', replace
			restore
		}
		
		*Merge median price at all levels
			merge m:1 state sector sss item using `m_1_${zi}', nogen
			merge m:1 state sector item using `m_2_${zi}', nogen
			merge m:1 state item using `m_3_${zi}', nogen
			merge m:1 sector item using `m_4_${zi}', nogen
			merge m:1 item using `m_5_${zi}', nogen
		
		*Restrict median prices to 50 observations at each level			
			gen med_price_${zi} = med_1_${zi} if count_1_${zi}>=50
			gen imputed_level_${zi} = 1 if count_1_${zi}>=50
			
			replace med_price_${zi} = med_2_${zi} if count_2_${zi}>=50 & med_price_${zi}==.
			replace imputed_level_${zi} = 2 if count_2_${zi}>=50 & imputed_level_${zi}==.
			
			replace med_price_${zi} = med_3_${zi} if count_3_${zi}>=50 & med_price_${zi}==.
			replace imputed_level_${zi} = 3 if count_3_${zi}>=50 & imputed_level_${zi}==.
			
			replace med_price_${zi} = med_4_${zi} if count_4_${zi}>=50 & med_price_${zi}==.
			replace imputed_level_${zi} = 4 if count_4_${zi}>=50 & imputed_level_${zi}==.
			
			replace med_price_${zi} = med_5_${zi} if count_5_${zi}>=50 & med_price_${zi}==.	
			replace imputed_level_${zi} = 5 if count_5_${zi}>=50 & imputed_level_${zi}==.
		
			label define imputed_level ///
			1 "state sector sss item" ///
			2 "state sector item" ///
			3 "state item" ///
			4 "sector item" ///
			5 "item"			
			label values imputed_level_${zi} "imputed_level"
					
		*Replace unit value with imputed median prices for observations flagged as outliers
			gen uv_def_${zi} = uv_def
			replace uv_def_${zi} = med_price_${zi} if out_${zi}_uv_def==1
			
		*Impute expenditure after imputing median prices		
		gen value_deflated${zs} = value_deflated_all
		replace value_deflated${zs} = qty_new * uv_def_${zi} if out_${zi}_uv_def==1 
		assert value_deflated${zs}!=value_deflated_all if out_${zi}_uv_def==1
			
		drop med_1_${zi} med_2_${zi} med_3_${zi} med_4_${zi} med_5_${zi} count*
		
		lab var uv_def "Unit value adjusted for within year price variation"
		lab var out_${zi}_uv_def "Outliers flagged at ${zi} standard deviation"
		lab var pwt "Population weights"
		lab var med_price_${zi} "Median price using non-outliers detected at ${zi}SD"
		lab var uv_def_${zi} "Imputed unit values for outliers detected at ${zi}SD"
		lab var imputed_level_${zi} "Level at which median prices are imputed for outliers detected at ${zi}SD"
		lab var value_deflated${zs} "Imputed value for outliers detected at ${zi}SD"
		lab var qty_new "Adjusted quantity"
		
	save "${user}/data/processed/ces/sensitivity_checks/outliers/master_consumption_wy_`j'${zs}.dta", replace
	}		
	
	*===============================================================================
		di in red "THE END OF 04_outliers_flags_deflators_wy${zs}" 
	*===============================================================================
	cap log close
	exit